@@ -38,8 +38,8 @@ pub struct FastRoundResultAccountData {
     pub result: FastRoundResult,
 }
 
-impl AnchorSerialize for FastRoundResultAccountData {
-    fn serialize<W>(&self, writer: &mut W) -> Result<(), Error> where W: Write {
+impl FastRoundResultAccountData {
+    pub fn serialize<W>(&self, writer: &mut W) -> Result<(), Error> where W: Write {
         let buf = self.as_bytes().to_vec();
         let mut res: Vec<u8> = vec![
             SwitchboardAccountType::TYPE_AGGREGATOR_RESULT_PARSE_OPTIMIZED as u8];
@@ -47,10 +47,8 @@ impl AnchorSerialize for FastRoundResultAccountData {
         writer.write_all(&res)?;
         Ok(())
     }
-}
 
-impl AnchorDeserialize for FastRoundResultAccountData {
-    fn deserialize(buf: &mut &[u8]) -> Result<Self, std::io::Error> {
+    pub fn deserialize(buf: &mut &[u8]) -> Result<Self, std::io::Error> {
         if buf.len() == 0 || buf[0] != SwitchboardAccountType::TYPE_AGGREGATOR_RESULT_PARSE_OPTIMIZED as u8 {
             return Err(std::io::Error::new(std::io::ErrorKind::InvalidInput, "Invalid buffer account type"));
         }
